==> haskell-hosc-0.17-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hosc
version: 0.17
id: hosc-0.17-BPnPLwXx6SmJGv8Spv6X5G
key: hosc-0.17-BPnPLwXx6SmJGv8Spv6X5G
license: GPL-3.0-only
copyright: (c) Rohan Drape, Stefan Kersten and others, 2007-2018
maintainer: rd@rohandrape.net
author: Rohan Drape, Stefan Kersten
stability: Experimental
homepage: http://rohandrape.net/t/hosc
synopsis: Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.
    .
    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".
category: Sound
abi: 07b3dbe761cdba37f7b3400f36049519
exposed: True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait
import-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hosc-0.17
hs-libraries: HShosc-0.17-BPnPLwXx6SmJGv8Spv6X5G
depends:
    base-4.12.0.0 binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    data-binary-ieee754-0.4.4-Jh3qq4jPu7AAxCF7JMXnJo
    network-2.8.0.0-1DkaUVvVIsp8sj7KmlE9xl time-1.8.0.2
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html: /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hosc-0.17-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hosc
version: 0.17
id: hosc-0.17-BhQbl46ij8gDYR9tHzj2BV
key: hosc-0.17-BhQbl46ij8gDYR9tHzj2BV
license: GPL-3.0-only
copyright: (c) Rohan Drape, Stefan Kersten and others, 2007-2018
maintainer: rd@rohandrape.net
author: Rohan Drape, Stefan Kersten
stability: Experimental
homepage: http://rohandrape.net/t/hosc
synopsis: Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.
    .
    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".
category: Sound
abi: 36dc5f1233c1ff893fb4d03486e272ab
exposed: True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait
import-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hosc-0.17
hs-libraries: HShosc-0.17-BhQbl46ij8gDYR9tHzj2BV
depends:
    base-4.12.0.0 binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    data-binary-ieee754-0.4.4-Jh3qq4jPu7AAxCF7JMXnJo
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R time-1.8.0.2
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html: /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
